@@ -1,6 +1,7 @@
-from django.core.cache.backends.base import DEFAULT_TIMEOUT
 from django.core.cache.backends.dummy import DummyCache
 
+from cascache.compatibility import DEFAULT_TIMEOUT
+
 
 class CASMixin(object):
     def cas(self, key, update_func, timeout=DEFAULT_TIMEOUT, version=None):
