@@ -1,7 +1,7 @@
 from django.conf import settings
-from django.core.cache.backends.base import DEFAULT_TIMEOUT
 from django.core.cache.backends.memcached import MemcachedCache, PyLibMCCache
 
+from cascache.compatibility import DEFAULT_TIMEOUT
 from cascache.exceptions import NoneValueError
 
 MAX_RETRIES = getattr(settings, 'CAS_CACHE_MAX_RETRIES', 10)
